# -*- coding: utf-8 -*-

from PyQt5.QtGui import QIcon
from PyQt5.QtDesigner import QPyDesignerCustomWidgetPlugin

from widgets.lineedit import LineEdit


class LineEditPlugin(QPyDesignerCustomWidgetPlugin):
    """Provides a Python custom plugin for Qt Designer by implementing the
    QDesignerCustomWidgetPlugin using a PyQt-specific custom plugin class.
    """

    def __init__(self, parent=None):
        super(LEditPlugin, self).__init__(parent)
        self.initialized = False

    def initialize(self, core):
        if self.initialized:
            return
        self.initialized = True

    def isInitialized(self):
        return self.initialized

    def createWidget(self, parent):
        """retourne une instance de la classe qui définit le nouveau widget
        """
        return LineEdit(parent)

    def name(self):
        """définit le nom du widget dans QtDesigner
        """
        return 'LineEdit'

    def group(self):
        """définit le nom du groupe de widgets dans QtDesigner
        """
        return 'Custom'

    def icon(self):
        """retourne l'icone qui represente le widget dans Designer
           => un QIcon() ou un QIcon(imagepixmap)
        """
        return QIcon()

    def toolTip(self):
        """retourne une courte description du widget comme tooltip
        """
        return "Un QLineEdit avec un fond jaune"

    def whatsThis(self):
        """retourne une courte description du widget pour le "What's this?"
        """
        return "Un QLineEdit avec un fond jaune"

    def isContainer(self):
        """dit si le nouveau widget est un conteneur ou pas
        """
        return False

    def domXml(self):
        """donne des propriétés du widget pour utilisation dans Designer
        """
        return '<widget class="LineEdit" name="LineEdit">\n'

    def includeFile(self):
        """retourne le nom du fichier (str sans extension) du widget
        """
        return 'widgets.lineedit'
